@@ -6,7 +6,6 @@ import os
 import json
 import hashlib
 from json import JSONDecodeError
-from ..ignores import parse_ignore
 from zipfile import ZipFile
 
 def get_config():
@@ -63,17 +62,20 @@ def build_package():
     # copy "tocopy"
 
     for route in TOCOPY:
-        os.makedirs(os.path.dirname(os.path.join(BUILD_HERE, route)), exist_ok=True)
         if os.path.isfile(route):
+            os.makedirs(os.path.dirname(os.path.join(BUILD_HERE, route)), exist_ok=True)
             print(f'Copying file {route}')
             shutil.copyfile(os.path.abspath(route), os.path.join(BUILD_HERE, route))
         else:
+            os.makedirs(os.path.join(BUILD_HERE, route), exist_ok=True)
             print(f'Copying tree {route}')
             shutil.rmtree(os.path.join(BUILD_HERE, route))
             shutil.copytree(os.path.abspath(route), os.path.join(BUILD_HERE, route))
 
     for root, _, file_list in os.walk(SRC_PROJECT_FOLDER):
         for file_item in file_list:
+            if root.find('__pycache__') >= 0:
+                continue
             src = os.path.join(root, file_item)
             dst = os.path.join(BUILD_HERE, os.path.relpath(root), file_item)
             
